#
# spec file for package nanoxml
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2000-2005, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nanoxml
Version:        2.2.3
Release:        6.4
Summary:        Small non-validating XML parser for Java
License:        Zlib
Group:          Development/Libraries/Java
URL:            http://nanoxml.sourceforge.net/orig/
Source0:        NanoXML-2.2.3.tar.bz2
Source1:        %{name}-java-1.4.2-package-list
Patch0:         %{name}-build.patch
Patch1:         %{name}-%{version}_enum.patch
Patch2:         %{name}-jar-mtime.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-tools
BuildRequires:  unzip
Requires:       java >= 1.8
Recommends:     %{name}-manual = %{version}
BuildArch:      noarch

%description
NanoXML is a small non-validating parser for Java.
The full parser with builder fits in a JAR file of about 32K.

%package        lite
Summary:        Lite version of %{name}
Group:          Development/Libraries/Java
Recommends:     %{name}-manual-lite = %{version}

%description    lite
NanoXML/Lite is the successor of NanoXML 1.x. It is still small (only
6KB) and features a much faster algorithm. It is recommended if you
are currently using NanoXML 1.x and do not want to adapt your code
for the new API or if you are coding applications that have to be
very small (like applets or embedded code). Please note that
NanoXML/Lite has only limited functionality (no mixed content, DTD is
ignored...).

%package        manual
Summary:        Manual for %{name}
Group:          Documentation/Other
Recommends:     %{name} = %{version}

%description    manual
Documentation for %{name}, a small non-validating XML parser.

%package        manual-lite
Summary:        Manual for the lite version of %{name}
Group:          Documentation/Other
Recommends:     %{name}-lite = %{version}

%description    manual-lite
Documentation for the lite version of %{name}.

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/Other

%description    javadoc
Java documentation for %{name}.

%prep
%setup -q -n NanoXML-%{version}
%patch -P 0
%patch -P 1
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 17}%{!?pkg_vcmp:0}
%patch -P 2 -p1
%endif
cp %{SOURCE1} package-list
find . -name "*.jar" -delete

%build
sh ./build.sh

%install
# jars
install -dm 755 %{buildroot}%{_javadir}
install -pm 644 Output/%{name}-lite.jar \
  %{buildroot}%{_javadir}/%{name}-lite.jar
install -pm 644 Output/%{name}-sax.jar \
  %{buildroot}%{_javadir}/%{name}-sax.jar
install -pm 644 Output/%{name}.jar \
  %{buildroot}%{_javadir}/%{name}.jar

# javadoc
install -dm 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr Documentation/JavaDoc/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-sax.jar

%files lite
%{_javadir}/%{name}-lite.jar

%files manual
%doc Documentation/NanoXML-Java/*

%files manual-lite
%doc Documentation/NanoXML-Lite/*

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Wed Sep 25 2024 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * nanoxml-jar-mtime.patch
    + Use SOURCE_DATE_EPOCH for reproducible jar mtime
- Modified patch:
  * nanoxml-build.patch
    + Generate javadoc without hidden timestamps
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Mar 21 2022 Fridrich Strba <fstrba@suse.com>
- Removes patch:
  * nanoxml-2.2.3_build.patch
    + incorporated into nanoxml-build.patch
- Modified patch:
  * nanoxml-build.patch
    + incorporate nanoxml-2.2.3_build.patch
    + specify source and target levels 8
* Tue Feb  5 2019 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * nanoxml-2.2.3_build.patch
    + specify source level also for javadoc invocation
    + fixes build with recent OpenJDK 11.0.2
* Tue Sep 19 2017 fstrba@suse.com
- Modified patch:
  * nanoxml-2.2.3_build.patch
    + build with java source and target level 1.6
    + fixes build with jdk9
* Sun Jul 31 2016 jengelh@inai.de
- Update descriptions
* Sat Jul  9 2016 mailaender@opensuse.org
- spec file cleanup
* Tue Dec 30 2008 lars@linux-schulserver.de
- build for openSUSE-Education
- removed Epoch
- require java
- add (soft) dependencies for the manuals
* Wed Jul 19 2006 Ralph Apel <r.apel@r-apel.de> - 0:2.2.3-4jpp
- First JPP-1.7 release
- Drop BR java-javadoc, add package-list as Source instead
* Sun Aug 22 2004 Fernando Nasser <fnasser@redhat.com> - 0:2.2.3-3jpp
- Updated URL
- Pro-forma rebuild with Ant 1.6.2 present
  Sat Jan 10 00:00:00 CET 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:2.2.3-2jpp
- Add Epoch.
- Change group to Text Processing/Markup/XML.
- Add unversioned javadoc dir symlinks, mark javadoc as %%%%doc.
- Install manual as normal %%%%doc, not into %%%%{_javadocdir}.
- BuildRequires java-devel (not ant).
- Don't use bundled SAX jar.
* Fri Dec 26 2003 Thomas Leonard <tle@sirius.sued.tremium.de> - 2.2.3-1
- Initial build.
